IOCopySystemLoadAdvisoryDetailed

Function IOCopySystemLoadAdvisoryDetailed 

pub extern "C-unwind" fn IOCopySystemLoadAdvisoryDetailed() -> Option<CFRetained<CFDictionary>>
Available on crate feature pwr_mgt only.
Indicates how user activity, battery level, and thermal level each contribute to the overall “SystemLoadAdvisory” level. In the future, this combined level may represent new levels as well.

See dictionary keys defined above.

Returns: Returns a CFDictionaryRef, or NULL on error. Caller must release the returned dictionary.