IONetworkReadData

Function IONetworkReadData 

pub unsafe extern "C-unwind" fn IONetworkReadData(
    con_obj: io_connect_t,
    data_handle: IONDHandle,
    dest_buf: *mut u8,
    in_out_size_p: *mut u32,
) -> IOReturn
Available on crate features libc and network only.
Read the buffer of a network data object.

Parameter conObj: The connection object.

Parameter dataHandle: The handle of a network data object.

Parameter destBuf: The buffer where the data read shall be written to.

Parameter inOutSizeP: Pointer to an integer that the caller must initialize to contain the size of the buffer. This function will overwrite it with the actual number of bytes written to the buffer.

Returns: kIOReturnSuccess on success, or an error code otherwise.

Safety

  • dest_buf must be a valid pointer.
  • in_out_size_p must be a valid pointer.