IONetworkWriteData

Function IONetworkWriteData 

pub unsafe extern "C-unwind" fn IONetworkWriteData(
    con_obj: io_connect_t,
    data_handle: IONDHandle,
    src_buf: *mut u8,
    in_size: u32,
) -> IOReturn
Available on crate features libc and network only.
Write to the buffer of a network data object.

Parameter conObj: The connection object.

Parameter dataHandle: The handle of a network data object.

Parameter srcBuf: The data to write is taken from this buffer.

Parameter inSize: The size of the source buffer.

Returns: kIOReturnSuccess on success, or an error code otherwise.

Safety

src_buf must be a valid pointer.