IOPMCopyCPUPowerStatus

Function IOPMCopyCPUPowerStatus 

pub unsafe extern "C-unwind" fn IOPMCopyCPUPowerStatus(
    cpu_power_status: *mut *const CFDictionary,
) -> IOReturn
Available on crate feature pwr_mgt only.
Copy status of all current CPU power levels.

The returned dictionary may define some of these keys, as defined in IOPM.h:

  • kIOPMCPUPowerLimitProcessorSpeedKey
  • kIOPMCPUPowerLimitProcessorCountKey
  • kIOPMCPUPowerLimitSchedulerTimeKey

Parameter cpuPowerStatus: Upon success, a pointer to a dictionary defining CPU power; otherwise NULL. Pointer will be populated with a newly created dictionary upon successful return. Caller must release dictionary.

Returns: kIOReturnSuccess, or other error report. Returns kIOReturnNotFound if CPU PowerStatus has not been published.

Safety

cpu_power_status must be a valid pointer.