pub unsafe extern "C-unwind" fn IONetworkGetDataHandle(
con_object: io_connect_t,
data_name: *const c_char,
data_handle_p: *mut IONDHandle,
) -> IOReturnAvailable on crate features
libc and network only.Expand description
Get the handle of a network data object with the given name.
Parameter conObject: The connection object.
Parameter dataName: The name of the network data object.
Parameter dataHandleP: Upon success, the handle is written to this address.
Returns: kIOReturnSuccess on success, or an error code otherwise.
Safety
data_namemust be a valid pointer.data_handle_pmust be a valid pointer.