pub unsafe extern "C-unwind" fn IONetworkSetPacketFiltersMask(
connect: io_connect_t,
filter_group: *mut [c_char; 128],
filters_mask: u32,
options: IOOptionBits,
) -> IOReturnAvailable on crate features
libc and network only.Expand description
Set the packet filters for a given filter group.
A network controller may support a number of packets filters that can accept or reject a type of packet seen on the network. A filter group identifies a set of related filters, such as all filters that will allow a packet to pass upstream based on the destination address encoded within the packet. This function allows an user-space program to set the filtering performed by a given filter group.
Parameter connect: The connection object returned from IONetworkOpen().
Parameter filterGroup: The name of the packet filter group.
Parameter filtersMask: A mask of filters to set.
Parameter options: No options are currently defined.
Returns: An IOReturn error code.
Safety
filter_group Array TODO.