pub extern "C-unwind" fn IOPSGetTimeRemainingEstimate() -> CFTimeIntervalps only.Expand description
Returns the estimated minutes remaining until all power sources
(battery and/or UPS’s) are empty, or returns
kIOPSTimeRemainingUnlimitedIf attached to an “Unlimited” power source, like AC power or any external source, the
return value is
kIOPSTimeRemainingUnlimitedIf the system is on “Limited” power, like a battery or UPS,
but is still calculating the time remaining, which may
take several seconds after each system power event
(e.g. waking from sleep, or unplugging AC Power), the return value is
kIOPSTimeRemainingUnknownOtherwise, if the system is on “Limited” power and the system has an accurate time remaining estimate, the system returns a CFTimeInterval estimate of the time remaining until the system is out of battery power.
If you require more detailed battery information, use
IOPSCopyPowerSourcesInfoand
IOPSGetPowerSourceDescription
.
Returns: Returns
kIOPSTimeRemainingUnknownReturns
kIOPSTimeRemainingUnlimitedOtherwise returns a positive number of type CFTimeInterval, indicating the time remaining in seconds until all power sources are depleted.